@@ -1,6 +1,6 @@
 package Beam::Wire;
 # ABSTRACT: Lightweight Dependency Injection Container
-$Beam::Wire::VERSION = '1.015';
+$Beam::Wire::VERSION = '1.016';
 use strict;
 use warnings;
 
@@ -230,6 +230,13 @@ sub create_service {
     }
 
     use_module( $service_info{class} );
+
+    if ( my $with = $service_info{with} ) {
+        my @roles = ref $with ? @{ $with } : ( $with );
+        my $class = Moo::Role->create_class_with_roles( $service_info{class}, @roles );
+        $service_info{class} = $class;
+    }
+
     my $method = $service_info{method} || "new";
     my $service;
     if ( ref $method eq 'ARRAY' ) {
@@ -249,11 +256,6 @@ sub create_service {
         $service = $service_info{class}->$method( @args );
     }
 
-    if ( my $with = $service_info{with} ) {
-        my @roles = ref $with ? @{ $with } : ( $with );
-        Moo::Role->apply_roles_to_object( $service, @roles );
-    }
-
     if ( $service_info{on} ) {
         my %meta = $self->get_meta_names;
         my @listeners;
@@ -528,7 +530,7 @@ sub validate {
 
 
 package Beam::Wire::Exception;
-$Beam::Wire::Exception::VERSION = '1.015';
+$Beam::Wire::Exception::VERSION = '1.016';
 use Moo;
 with 'Throwable';
 use Types::Standard qw( :all );
@@ -541,7 +543,7 @@ has error => (
 
 
 package Beam::Wire::Exception::Constructor;
-$Beam::Wire::Exception::Constructor::VERSION = '1.015';
+$Beam::Wire::Exception::Constructor::VERSION = '1.016';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -554,7 +556,7 @@ has attr => (
 
 
 package Beam::Wire::Exception::Config;
-$Beam::Wire::Exception::Config::VERSION = '1.015';
+$Beam::Wire::Exception::Config::VERSION = '1.016';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -582,7 +584,7 @@ has '+error' => (
 
 
 package Beam::Wire::Exception::Service;
-$Beam::Wire::Exception::Service::VERSION = '1.015';
+$Beam::Wire::Exception::Service::VERSION = '1.016';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -600,7 +602,7 @@ has file => (
 
 
 package Beam::Wire::Exception::NotFound;
-$Beam::Wire::Exception::NotFound::VERSION = '1.015';
+$Beam::Wire::Exception::NotFound::VERSION = '1.016';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 
@@ -616,7 +618,7 @@ has '+error' => (
 
 
 package Beam::Wire::Exception::InvalidConfig;
-$Beam::Wire::Exception::InvalidConfig::VERSION = '1.015';
+$Beam::Wire::Exception::InvalidConfig::VERSION = '1.016';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 use overload q{""} => sub {
@@ -642,7 +644,7 @@ Beam::Wire - Lightweight Dependency Injection Container
 
 =head1 VERSION
 
-version 1.015
+version 1.016
 
 =head1 SYNOPSIS
 
